==> nextcloud-30.0.5.tgz: nextcloud/apps/twofactor_nextcloud_notification/l10n/pt_BR.js <==
OC.L10N.register(
    "twofactor_nextcloud_notification",
    {
    "TwoFactor Nextcloud notification" : "Notificação Nextcloud de dois fatores",
    "Approve" : "Aprovar",
    "Cancel" : "Cancelar",
    "Login attempt from IP address {ip}" : "Tentativa de login do endereço IP {ip}",
    "If you are currently trying log in from another device or browser please approve the request. If you are not trying to log in at the moment, you should use the cancel option to abort the login attempt." : "Se você está tentando fazer login de outro dispositivo ou navegador, aprove a solicitação. Se você não estiver tentando fazer login no momento, você deve usar a opção cancelar para abortar a tentativa de login.",
    "Nextcloud Notification" : "Notificação Nextcloud",
    "Authenticate using a device that is already logged in to your account" : "Autenticar usando um dispositivo que já está conectado à sua conta",
    "Two-Factor Authentication via Nextcloud notification" : "Autenticação de dois fatores via notificação Nextcloud",
    "Allows using any of your logged in devices as second factor" : "Permite usar qualquer um dos seus dispositivos conectados como segundo fator",
    "Please accept the request on one of your logged in devices." : "Por favor, aceite o pedido em um de seus dispositivos conectados.",
    "You will be redirected automatically once this login has been accepted." : "Você será redirecionado automaticamente assim que este login for aceito.",
    "Please wait …" : "Por favor espere...",
    "Your login attempt was rejected." : "Sua tentativa de login foi rejeitada.",
    "Use two-factor authentication via Nextcloud notifications" : "Use autenticação de dois fatores via notificações do Nextcloud"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-31.0.9.tgz: nextcloud/apps/twofactor_nextcloud_notification/l10n/pt_BR.js <==
OC.L10N.register(
    "twofactor_nextcloud_notification",
    {
    "TwoFactor Nextcloud notification" : "Notificação Nextcloud de dois fatores",
    "Approve" : "Aprovar",
    "Cancel" : "Cancelar",
    "Login attempt from IP address {ip}" : "Tentativa de login do endereço IP {ip}",
    "If you are currently trying log in from another device or browser please approve the request. If you are not trying to log in at the moment, you should use the cancel option to abort the login attempt." : "Se estiver tentando fazer login de outro dispositivo ou navegador, aprove a solicitação. Se não estiver tentando fazer login no momento, use a opção cancelar para abortar a tentativa de login.",
    "Nextcloud Notification" : "Notificação Nextcloud",
    "Authenticate using a device that is already logged in to your account" : "Autenticar usando um dispositivo que já está conectado à sua conta",
    "Two-Factor Authentication via Nextcloud notification" : "Autenticação de dois fatores via notificação Nextcloud",
    "Allows using any of your logged in devices as second factor" : "Permite usar qualquer um dos seus dispositivos conectados como segundo fator",
    "Please accept the request on one of your logged in devices." : "Por favor, aceite o pedido em um de seus dispositivos conectados.",
    "You will be redirected automatically once this login has been accepted." : "Você será redirecionado automaticamente assim que este login for aceito.",
    "Please wait …" : "Por favor espere...",
    "Your login attempt was rejected." : "Sua tentativa de login foi rejeitada.",
    "Use two-factor authentication via Nextcloud notifications" : "Use autenticação de dois fatores via notificações do Nextcloud"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
